// ********************************************************************
// ROOT macro: plot_comparison.c
// Reads EPICS2017 data produced by the generate_pp_cs.c macro
// and written in the livermore_epics2017 directory:
//    pairdata   => intermediate files containing pure pair production cs
//    tripdata   => intermediate files containing triplet production cs before interpolation
//    tripInterp => intermediate files containing the interpolated 
//                                    version of triplet production cs
//    pair       => final files for total pair production = pair + interpolated triplet EPDL2017.ALL 
//
// for all chemical elements (Z=1 to 100).
// This macro must be placed in the same directory as the livermore_epics2017 directory.
// 
// Generates 100 cross section data files in the directory 
// pair_EPICS2017(one file per element) in compliance with the livermore 
// GEANT4 format.
// The macro creates 4 directories, in which the generated files are placed :
//    pairdata   => intermediate files containing pure pair production cs
//    tripdata   => intermediate files containing triplet production cs before interpolation
//    tripInterp => intermediate files containing the interpolated 
//                                    version of triplet production cs
//    pair       => final files for total pair production = pair + interpolated triplet
// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// ********************************************************************



TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(Double_t number)
  {
    stringstream ss;
    TString ts = ss.str();
    return ts;
  }
  
void plot_comparison()
{
	gROOT->Reset();
	string dirs[5] = {"plots","epics2017"};
	for (Int_t i=0;i<2;++i)
	{
		// create the 5 directories if they do not existif
		if(i==0)
		{
			dirs[i] = "mkdir -p "+dirs[i]; 
		// execute the command defined line above
		gSystem->Exec(dirs[i].c_str());
		}
		else 
		{
			dirs[i] = "mkdir -p plots/" + dirs[i]; 
			gSystem->Exec(dirs[i].c_str());
		}
		
		
	}
	
	for (Int_t z = 1;z<=1;++z)// number of element Z, from 1 to 100
	{
		char file1Format[128] = "livermore_epics2017/pairdata/pp-pair-cs-%d.dat"; //prefix of the name of original data file
		char file1[128];
		
		char file2Format[128] = "livermore_epics2017/tripdata/pp-trip-cs-%d.dat"; //prefix of the name of original data file
		char file2[128];
	
		char file3Format[128] = "livermore_epics2017/tripInterp/pp-tripInterp-cs-%d.dat"; //prefix of the name of original data file
		char file3[128];
		
		char file4Format[128] = "livermore_epics2017/pair/pp-cs-%d.dat"; //prefix of the name of original data file
		char file4[128];
		
		sprintf(file1,file1Format, z);
		sprintf(file2,file2Format, z);
		sprintf(file3,file3Format, z);
		sprintf(file4,file4Format, z);
		
		TString S = sInt(z); 
		TString title;
		title = "EPICS2017 pure pair, triplet, interpolated triplet \
		and total pair production cross section for element Z = " + S;
			
			
		Int_t num1 = 0;  
		Int_t num2 = 0; 
		Int_t num3 = 0;  
		
		
		Int_t ncols;
		double e, cs;
		Int_t loop = 0;
		char str[64] = "";
		
			
			
		FILE * fp1 = fopen(file1,"r");  // open files for pair production

		while(1)
		{	
			loop++;
			fgets (str, 64, fp1);
			if(loop ==2)
			{
				num1 = stoi(str);  //read the second line, namely the number of points
				// cout<<num1<<endl;
				break;
			}		
			
		}
		
		double x_1[num1]; // array for pair production data: energy
		double y_1[num1]; // array for pair production data: cross section
		
		for(Int_t i = 0;i<num1;++i)
		{
			ncols = fscanf(fp1,"%lf %lf",&e,&cs); 
			x_1[i]=e;
			y_1[i]=cs;
			//printf("i==%d, %.9e %.9e\n",i, x_1[i],y_1[i]);
		}
		fclose(fp1);
		
		
		FILE * fp2 = fopen(file2,"r");	// open files for triplet production	
		loop =0;
		while(1)
		{	
			loop++;
			fgets (str, 64, fp2);
			if(loop ==2)
			{
				num2 = stoi(str);  //read the second line, namely the number of points
				//cout<<num2<<endl;
				break;
			}		
			
		}
		double x_2[num2]; // array for triplet production data: energy
		double y_2[num2]; // array for triplet production data: cross section
		
		for(Int_t i = 0;i<num2;++i)
		{
			ncols = fscanf(fp2,"%lf %lf",&e,&cs); 
			x_2[i]=e;
			y_2[i]=cs;
			// printf("%.9e %.9e\n",x_2[i],y_2[i]);
		}
		fclose(fp2);
		
		FILE * fp3 = fopen(file3,"r");	// open files for triplet production	
		loop =0;
		while(1)
		{	
			loop++;
			fgets (str, 64, fp3);
			if(loop ==2)
			{
				num3 = stoi(str);  //read the second line, namely the number of points
				//cout<<num3<<endl;
				break;
			}		
			
		}
		double x_3[num3]; 
		double y_3[num3]; 
		
		
		for(Int_t i = 0;i<num3;++i)
		{
			ncols = fscanf(fp3,"%lf %lf",&e,&cs); 
			x_3[i]=e;
			y_3[i]=cs;
			// printf("%.9e %.9e\n",x_3[i],y_3[i]);
		}
		fclose(fp3);
		
		
		FILE * fp4 = fopen(file4,"r");	// open files for triplet production	
		loop =0;
		while(1)
		{	
			loop++;
			fgets (str, 64, fp4);
			if(loop ==2)
			{
				
				break;
			}		
			
		}
		double x_4[num1]; 
		double y_4[num1]; 
		double r[num1]; 
		
		for(Int_t i = 0;i<num1;++i)
		{
			ncols = fscanf(fp4,"%lf %lf",&e,&cs); 
			x_4[i]=e;
			y_4[i]=cs;
			
			if(cs == 0) 
			{
				r[i] = 0;
				continue;
			}
			r[i] = (cs-y_1[i])/cs;    // triplet/(pair+triplet)
			
		}
		fclose(fp4);	
		
		
		
		
		TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",500, 50, 1000, 600);
		
		
		
		mycanvas->Divide(1,2);
		
		mycanvas->cd(1);
		gPad->SetLogx();
		gPad->SetLogy();
		gPad->SetGrid();
		
		TMultiGraph *mg =new TMultiGraph();
		TGraph *graph1 = new TGraph(num1,x_1,y_1);  //pure pair 
		TGraph *graph2 = new TGraph(num2,x_2,y_2);  // triplet
		TGraph *graph3 = new TGraph(num3,x_3,y_3);   
		TGraph *graph4 = new TGraph(num1,x_4,y_4);

		
		graph2->SetMarkerStyle(4);  //blue circle
		graph2->SetMarkerSize(0.7);
		graph2->SetMarkerColor(4);
		graph2->SetLineColor(4);
		mg->Add(graph2);
		
		

		
		
		graph1->SetMarkerStyle(7);  // red point
		graph1->SetMarkerSize(2);
		graph1->SetMarkerColor(2);
		//graph1->SetLineWidth(2);
		graph1->SetLineColor(2);
		mg->Add(graph1);
		
		
		graph3->SetMarkerStyle(20);  
		graph3->SetMarkerSize(0.5);
		graph3->SetMarkerColor(6);
		graph3->SetLineColor(6);
		mg->Add(graph3);
		
		graph4->SetMarkerStyle(4);  // red point
		graph4->SetMarkerSize(0.5);
		graph4->SetMarkerColor(1);
		//graph4->SetLineWidth(2);
		graph4->SetLineColor(1);
		mg->Add(graph4);
		mg->Draw("APL"); 
		
		
		
		mg->SetTitle(title);
		
		mg->GetXaxis()->SetTitle("Energy (MeV)");
		mg->GetYaxis()->SetTitle("Cross section (mm^{2})");
		
		mg->GetXaxis()->SetTitleSize(0.06);
		mg->GetYaxis()->SetTitleSize(0.06);
		
		mg->GetXaxis()->SetLabelSize(0.06);
		mg->GetYaxis()->SetLabelSize(0.06);
		
		mg->GetXaxis()->SetTitleOffset(0.7);
		mg->GetYaxis()->SetTitleOffset(0.6);
		
		
		mg->GetXaxis()->CenterTitle();
		mg->GetYaxis()->CenterTitle();
		
		mg->GetXaxis()->SetLimits(1,100000.);
		
		TLegend* leg1 = new TLegend(.6,.1,.9,.4);
		leg1->SetFillColor(0);
		
		
		
		
		TString Tnum1 = sInt(num1);		
		TString Tnum2 = sInt(num2);	
		TString Tnum3 = sInt(num3);		
		

		TString name1 = "pure pair production - " + Tnum1 + " points";
		TString name2 = "triplet production - " + Tnum2 + " points";
		TString name3 = "interpolated triplet - " + Tnum3 + " points";
		TString name4 = "total pair production - " + Tnum1 + " points";
		
		
		leg1->AddEntry(graph1,name1);
		leg1->AddEntry(graph2,name2);
		leg1->AddEntry(graph3,name3);
		leg1->AddEntry(graph4,name4);
		
		
		leg1->Draw();
		leg1->SetTextSize(0.045);
		
		
		
		
		
		
		
		mycanvas->cd(2);
		gPad->SetLogx();
		gPad->SetGrid();
			
		TString nameRatio = "Ratio of triplet over total pair production cross section";	
		
		TGraph *ratio = new TGraph(num1,x_1,r);
		ratio->Draw();
		ratio->SetTitle(nameRatio);
		
		
		TLegend* leg2 =  new TLegend(0.7,0.1,0.9,0.3,"ratio = #frac{triplet}{pure pair + triplet}");
		
		leg2->Draw(); 
		leg2->SetTextAlign(22);
		leg2->SetTextSize(0.06);
		
		ratio->GetXaxis()->SetTitle("Energy (MeV)");
		ratio->GetYaxis()->SetTitle("Ratio of triplet");
		
		ratio->GetXaxis()->SetTitleSize(0.06);
		ratio->GetYaxis()->SetTitleSize(0.06);
		
		ratio->GetXaxis()->SetLabelSize(0.06);
		ratio->GetYaxis()->SetLabelSize(0.06);
		
		ratio->GetXaxis()->SetTitleOffset(0.7);
		ratio->GetYaxis()->SetTitleOffset(0.6);
		
		ratio->GetXaxis()->CenterTitle();
		ratio->GetYaxis()->CenterTitle();
		
		
		
		ratio->SetMarkerStyle(8);
		ratio->SetMarkerSize(0.5);
		ratio->SetMarkerColor(2);
		ratio->SetLineColor(2);
		
		mycanvas->Print("plots/epics2017/EPICS2017-comparison-" + S + ".gif");
		// mycanvas->Close();
			
	
	}
	
		
}

