// **************************************************************************
// ROOT macro: plot_trip.c
// Plots the figures of triplet gamma conversion cross section data. 
// There is one figure (now in png format, it can be modified) per element.
// -	cross section data of EPICS2017 (Z: 1-100)    
// -	cross section data of Livermore (Z: 1-99)   
// -	comparison of cross section data between Livermore and EPICS2017 (Z: 1-99)  
// The generated figures are saved in the corresponding directory:
// -	plots/trip/comparison
// -	plots/trip/epics2017
// -	plots/trip/livermore

// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// **************************************************************************
TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(Double_t number)
  {
    stringstream ss;
    TString ts = ss.str();
    return ts;
  }
  
int results=0;

void plotSingle(Int_t z, Int_t plot, char*dir)
{
	
	TString S = sInt(z);  
	
	TString title;
	
	
	if (plot == 1)
	{
		title = "EPICS2017 triplet production cross section for element Z = " + S;
		
	}
	else if(plot == 2)
	{
		title = "Livermore triplet production cross section for element Z = " + S;
	}
	
		
		
	Int_t num = 0;  
	Int_t ncols;
	double e, cs;
	Int_t loop = 0;
	char str[64] = "";
	
	
	FILE * fp = fopen(dir,"r");

	while(1)  
	{	
		loop++;
		// if loop = 1 we read the first header line
		fgets (str, 64, fp);
		// cout<<str<<endl;
		if(loop ==2)
		{
			// now loop = 2, we read the second header line, namely the number of points
			num = stoi(str);  
			// cout<<"number of triplet production points:"<<num<<endl;
			break;
		}		
		
	}
	TString Tnum = sInt(num);
	
	double x[num];
	// array for triplet production data: cross section		
	double y[num]; 
	
	for(Int_t i = 0;i<num;++i)
	{
		// read one line energy cross section
		ncols = fscanf(fp,"%lf %lf",&e,&cs); 
		x[i]=e;   // keep energy
		y[i]=cs;  // keep cross section
		// printf("%.9e %.9e\n",x_1[i],y_1[i]);
	}
	fclose(fp);
	
	
    TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",0, 1, 900, 600);
		

	//TCanvas* mycanvas=new TCanvas(sz, sz, 200, 10, 1000, 1000);
	mycanvas->SetGrid();
	gPad->SetLogx();
	
	TGraph *graph = new TGraph(num,x,y);
	//graph->Draw("AC*");
	graph->Draw("APL");
	
	graph->SetMarkerStyle(7);  // red point
	graph->SetMarkerSize(2);
	graph->SetMarkerColor(2);
	//graph->SetLineWidth(2);
	graph->SetLineColor(2);
	
	graph->SetTitle(title);
	
	graph->GetXaxis()->SetTitle("Energy (MeV)");
	graph->GetYaxis()->SetTitle("Cross section (mm^{2})");
	
	graph->GetXaxis()->CenterTitle();
	graph->GetYaxis()->CenterTitle();
	
	graph->GetXaxis()->SetTitleOffset(1.2);
	
	TLegend* leg = new TLegend(0.1,.7,.39,.9);
	leg->SetFillColor(0);
	
	
	
	
	TString name;
	if (plot == 1)
	{
		name = "EPICS2017 - " + Tnum + " points";
		
	}
	else if(plot == 2)
	{
		name = "Livermore - " + Tnum + " points";
	}
	
	
	leg->AddEntry(graph,name);

	leg->Draw();
	
	
	
	if (plot == 1)
	{
		mycanvas->Print("plots/trip/epics2017/EPICS2017-pp-trip-cs-" + S + ".png");
		mycanvas->Close();
	}
	else if(plot == 2)
	{
		mycanvas->Print("plots/trip/livermore/Livermore-pp-trip-cs-" + S + ".png");
		mycanvas->Close();
	}
		
		
}

// void plotComparison(Int_t z, char*dir1, char*dir2)
// {
	
	// gROOT->Reset();
		
	// TString S = sInt(z); 
	// TString title;
	// title = "triplet production cross section for element Z = " + S;
		
		
	// Int_t num1 = 0;  
	// Int_t num2 = 0; 
	
	
	// Int_t ncols;
	// double e, cs;
	// Int_t loop = 0;
	// char str[64] = "";
	
	// FILE * fp1 = fopen(dir1,"r");
	
		// while(1)  
		// {	
			// loop++;
			// // if loop = 1 we read the first header line
			// fgets (str, 64, fp1);
			// // cout<<str<<endl;
			// if(loop ==2)
			// {
				// // now loop = 2, we read the second header line, namely the number of points
				// num1 = stoi(str);  
				// // cout<<"number of triplet production points:"<<num1<<endl;
				// break;
			// }		
			
		// }
		
		// double x_1[num1];		
		// double y_1[num1]; 
		
		// for(Int_t i = 0;i<num1;++i)
		// {
			// // read one line energy cross section
			// ncols = fscanf(fp1,"%lf %lf",&e,&cs); 
			// x_1[i]=e;   // keep energy
			// y_1[i]=cs;  // keep cross section
			// // printf("%.9e %.9e\n",x_1[i],y_1[i]);
		// }
		// fclose(fp1);
		
		// FILE * fp2 = fopen(dir2,"r");		
		// loop =0;
		
		// while(1)
		// {	
			// loop++;
			// // if loop = 1 we read the first header line
			// fgets (str, 64, fp2);
			// if(loop ==2)
			// {
				// // now loop = 2, we read the second header line, namely the number of points
				// num2 = stoi(str);  
				// // cout<<"number of triplet production points:"<<num2<<endl;
				// break;
			// }		
			
		// }
		
		// double x_2[num2]; 
		// double y_2[num2]; 
		
		// for(Int_t i = 0;i<num2;++i)
		// {
			// // read one line energy cross section
			// ncols = fscanf(fp2,"%lf %lf",&e,&cs); 
			// x_2[i]=e; // keep energy
			// y_2[i]=cs; // keep cross section
			// // printf("%.9e %.9e\n",x_2[i],y_2[i]);
		// }
		// fclose(fp2);
		
		
		// TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",500, 50, 1500, 700);
		
		// mycanvas->SetGrid();
		// mycanvas->Divide(1,2);
	
		
		
		// mycanvas->cd(1);
		// gPad->SetGrid();
		// gPad->SetLogx();
		// gPad->SetBottomMargin(0.15);
		// // gPad->SetLogy();
					
		// TGraph *graph1 = new TGraph(num1,x_1,y_1);
		// TGraph *graph2 = new TGraph(num2,x_2,y_2);
		
		// // set graph parameters of livermore
		// graph2->SetMarkerStyle(4);  //blue circle
		// graph2->SetMarkerSize(0.7);
		// graph2->SetMarkerColor(4);
		// graph2->SetLineColor(4);
		
		// graph2->Draw("APL");
	   
		
		// // set graph parameters of EPICS2017
		// graph1->SetMarkerStyle(7);  // red point
		// graph1->SetMarkerSize(2);
		// graph1->SetMarkerColor(2);
		// // graph1->SetLineWidth(2);
		// graph1->SetLineColor(2);	
		// graph1->Draw("PL");
				
		// graph2->SetTitle(title);
		
		// graph2->GetXaxis()->SetTitle("Energy (MeV)");
		// graph2->GetYaxis()->SetTitle("Cross section (mm^{2})");
		
		// graph2->GetXaxis()->SetTitleSize(0.06);
		// graph2->GetYaxis()->SetTitleSize(0.06);
		
		// graph2->GetXaxis()->SetLabelSize(0.05);
		// graph2->GetYaxis()->SetLabelSize(0.05);
		
		
		// graph2->GetXaxis()->CenterTitle();
		// graph2->GetYaxis()->CenterTitle();
		
		// graph2->GetXaxis()->SetLimits(1,100000.);
		
		// // graph2->SetMaximum(5e-25); 
		// // graph2->SetMinimum(1e-35); 
		
		
		// TLegend* leg = new TLegend(.1,.7,.42,.9);
		// leg->SetFillColor(0);	
		// leg->SetTextSize(0.06);
		
		
		// TString Tnum1 = sInt(num1);		
		// TString Tnum2 = sInt(num2);	
		
		// TString name1 = "EPICS2017 - "+ Tnum1 + " points";
		// TString name2 = "Livermore - "+ Tnum2 + " points";		
		
		// leg->AddEntry(graph1,name1);
		// leg->AddEntry(graph2,name2);
		// // leg->DrawClone("Same");
		// leg->Draw();
		
		// int flag=0;
		// double r[num2];  // ratio (%): (EPICS2017-Livermore)/Livermore *100 ;
		
		

		// for(Int_t i=num2-1;i>=0;--i)  //Livermore  
		// {
			// for(Int_t j=num1-1;j>=0;--j) //EPICS2017
			// {
				// if(x_1[j] == x_2[i]) 
				// {				
					// // cout<<flag<<"-----"<<x_2[i]<<endl;
					
					// if(y_2[i] == y_1[j]) //if(i==0)
					// {
						// r[i]=0;
						// // cout<<r[i]<<endl;
					// }
					// else 
					// {
						// r[i] = (y_1[j] - y_2[i])/y_2[i]*100;  //percentage
						// // cout<<x_1[j]<<"====="<<r[i]<<endl;
					// }
					// flag++;
					// // cout<<i<<"-----EPICS2017=="<<y_1[j]<<"-----Livermore==" << y_2[i]<<"*****Ratio=="<<r[i]<<endl;
					// break;
				
					
				// }
			// }
		// }
		
		// if(flag==num2) 
		// {
			// results++;
			// cout<<"flag=="<<flag<<endl;
			// cout<<"flag==num2,winnnnnnnnnnnnnn"<<endl;	
		// }
		
		
		
		// TPad *bottomPad = (TPad*)mycanvas->cd(2);
		// bottomPad->Divide(2,1);
		// bottomPad->cd(1);
		// gPad->SetLogx();
		// // gPad->SetTopMargin(0.12);
		// gPad->SetLeftMargin(0.12);
		// gPad->SetBottomMargin(0.15);
		// // gPad->SetGrid();
		// // gStyle->SetTitleW(0.9);  //per cent of the pad width
		// // gStyle->SetTitleH(0.9);
		// // gStyle->SetTitleFontSize(0.9);
		
		// pad21->SetLeftMargin(0.10); //10%
		
		
		// char nameRatio[100] = "Relative difference of EPICS2017 compared to Livermore";	
		
		// TGraph *ratio = new TGraph(num2,x_2,r);
		// ratio->SetTitle(nameRatio);
		// ratio->Draw();
		// ratio->GetXaxis()->SetTitle("Energy (MeV)");
		// ratio->GetYaxis()->SetTitle("Relative Diference (%)");
		
		// ratio->GetXaxis()->SetTitleSize(0.06);
		// ratio->GetYaxis()->SetTitleSize(0.06);
		
		// ratio->GetXaxis()->SetLabelSize(0.05);
		// ratio->GetYaxis()->SetLabelSize(0.05);
			
		// ratio->GetXaxis()->CenterTitle();
		// ratio->GetYaxis()->CenterTitle();
		
		// ratio->SetMarkerStyle(8);
		// ratio->SetMarkerSize(0.5);
		// ratio->SetMarkerColor(2);
		// ratio->SetLineColor(2);
		
		// TLegend* leg21 =  new TLegend(0.5,0.2,0.9,0.4,"RD = #frac{EPICS2017-Livermore}{Livermore} x 100");
		// leg21->SetTextAlign(22);
		// leg21->SetFillStyle(0);
		// leg21->Draw();
		// leg21->SetTextSize(0.05);
		
		
		
		
		
		// // ***********(begin)for the zoomin of the ratio 
		// Int_t num3=0;
		// for(Int_t i =num2-1;i>=0;--i)
		// {
			// // if(r[i]>=-0.1)
			// // {
				// // num3 =i+1;
				// // break;
			// // }
			
			// if(r[i]!=0)
			// {
				// num3 =i+5;
				// break;
			// }
			
		// }
		
		// bool zoomin = true;
		// if (num3 == 0)  zoomin = false;
	
		
		// // ***********(begin)for the zoomin of the ratio 
		
		
		
		// bottomPad->cd(2);
		// gPad->SetLeftMargin(0.12);
		// gPad->SetBottomMargin(0.15);
		
		// // pad22->SetLeftMargin(0.12);
		// // gPad->SetLogx();
		// // TGraph *zoomIn = new TGraph(num3,x_3,r_3);
		// if(zoomin)
		// {
			// // cout<<"*****zoomin points=="<<num3+1<<endl;
			// TGraph *zoomIn = new TGraph(num2,x_2,r);
			
			// zoomIn->Draw();
			// TString title = "Zoom on the low energy region";
			
			// zoomIn->SetTitle(title);	
			
			// zoomIn->GetXaxis()->SetTitle("Energy (MeV)");
			// zoomIn->GetYaxis()->SetTitle("Relative difference (%)");
			
			// zoomIn->GetXaxis()->SetTitleSize(0.06);
			// zoomIn->GetYaxis()->SetTitleSize(0.06);
		
			// zoomIn->GetXaxis()->SetLabelSize(0.05);
			// zoomIn->GetYaxis()->SetLabelSize(0.05);
			
			// zoomIn->GetXaxis()->CenterTitle();
			// zoomIn->GetYaxis()->CenterTitle();
			
			// zoomIn->SetMarkerStyle(8);
			// zoomIn->SetMarkerSize(0.5);
			// zoomIn->SetMarkerColor(2);
			// zoomIn->SetLineColor(2);
			
			// // printf("%f, %d",x_2[num3],num3 );
			// zoomIn->GetXaxis()->SetLimits(1,x_2[num3]);
			// // zoomIn->SetMinimum(-0.1);
			// // zoomIn->SetMaximum(0.01); 
		
		// }
		// else
		// {
			// TGraph *zoomIn = new TGraph(num2,x_2,r);
			
			// zoomIn->Draw();
			// TString title = "Zoom on the low energy region";
			
			// zoomIn->SetTitle(title);	
			
			// zoomIn->GetXaxis()->SetTitle("Energy (MeV)");
			// zoomIn->GetYaxis()->SetTitle("Relative difference (%)");
			
			// zoomIn->GetXaxis()->SetTitleSize(0.06);
			// zoomIn->GetYaxis()->SetTitleSize(0.06);
		
			// zoomIn->GetXaxis()->SetLabelSize(0.05);
			// zoomIn->GetYaxis()->SetLabelSize(0.05);
			
			// zoomIn->GetXaxis()->CenterTitle();
			// zoomIn->GetYaxis()->CenterTitle();
			// zoomIn->SetMarkerStyle(8);
			// zoomIn->SetMarkerSize(0.5);
			// zoomIn->SetMarkerColor(2);
			// zoomIn->SetLineColor(2);
			
			// // printf("%f, %d",x_2[num3],num3 );
			// zoomIn->GetXaxis()->SetLimits(1,3);
			
		// }
		
		
		// mycanvas->Print("plots/trip/comparison/comparison-pp-cs-"+ S +".png");
		// mycanvas->Close();
		
		
// }


void plotComparison_2(Int_t z, char*dir1, char*dir2)
{
	
	gROOT->Reset();
		
	TString S = sInt(z); 
	TString title;
	title = "Triplet production cross section for element Z = " + S;
		
		
	Int_t num1 = 0;  
	Int_t num2 = 0; 
	
	
	Int_t ncols;
	double e, cs;
	Int_t loop = 0;
	char str[64] = "";
	
	FILE * fp1 = fopen(dir1,"r");
	
		while(1)  
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp1);
			// cout<<str<<endl;
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num1 = stoi(str);  
				// cout<<"number of pure pair production points:"<<num1<<endl;
				break;
			}		
			
		}
		
		double x_1[num1];		
		double y_1[num1]; 
		
		for(Int_t i = 0;i<num1;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp1,"%lf %lf",&e,&cs); 
			x_1[i]=e;   // keep energy
			y_1[i]=cs*1e22;  // keep cross section   unit is barn
			// printf("%.9e %.9e\n",x_1[i],y_1[i]);
		}
		fclose(fp1);
		
		FILE * fp2 = fopen(dir2,"r");		
		loop =0;
		
		while(1)
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp2);
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num2 = stoi(str);  
				// cout<<"number of pure pair production points:"<<num2<<endl;
				break;
			}		
			
		}
		
		double x_2[num2]; 
		double y_2[num2]; 
		
		for(Int_t i = 0;i<num2;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp2,"%lf %lf",&e,&cs); 
			x_2[i]=e; // keep energy
			y_2[i]=cs*1e22; // keep cross section
			//printf("%.9e %.9e\n",x_2[i],y_2[i]);
		}
		fclose(fp2);
		
		
		TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",500, 50, 400, 400);
		
		mycanvas->SetGrid();
		// mycanvas->Divide(1,2);
		//TPad* pad1 = new TPad("pad1","This is pad1",0.05,0.52,0.95,0.97);
		// TPad* pad1 = new TPad("pad1","This is pad1",0.0,0.4,1.0,1.0);
		// TPad* pad2 = new TPad("pad2","This is pad2",0.0,0.0,1.0,0.4);
		// pad1->Draw();
		// pad2->Draw();
		
		// pad2->cd();
		// TPad* pad21 = new TPad("pad21","First subpad of pad2",0.1,0.0,0.5,1.0);
		// TPad* pad22 = new TPad("pad22","Second subpad of pad2",0.5,0.0,0.9,1.0);
		// pad21->Draw();
		// pad22->Draw();
		
		
		// mycanvas->cd(1);
		gPad->SetGrid();
		gPad->SetLogx();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		//gPad->SetLogy();
		auto mg = new TMultiGraph();			
		TGraph *graph1 = new TGraph(num1,x_1,y_1);
		TGraph *graph2 = new TGraph(num2,x_2,y_2);
		
		
		//set graph parameters of EPICS2017
		graph1->SetMarkerStyle(24);  // red point
		graph1->SetMarkerSize(1.4);
		graph1->SetMarkerColor(kRed);
		//graph1->SetLineWidth(2);
		// graph1->SetLineColor(kRed);	
		mg->Add(graph1);
		
		//set graph parameters of livermore
		graph2->SetMarkerStyle(21);  //blue circle
		graph2->SetMarkerSize(0.8);
		graph2->SetMarkerColor(kBlue);
		graph2->SetLineColor(kBlue);
		
		mg->Add(graph2);
	   
		
		
				
		mg->Draw("AP");
		mg->SetTitle(title);
		mg->GetXaxis()->SetTitle("Energy (MeV)");
		mg->GetYaxis()->SetTitle("Cross section (barn)");
		
		// mg->GetXaxis()->SetTitleSize(0.06);
		// mg->GetYaxis()->SetTitleSize(0.06);
		
		// mg->GetXaxis()->SetLabelSize(0.05);
		// mg->GetYaxis()->SetLabelSize(0.05);
		
		
		mg->GetXaxis()->CenterTitle();
		mg->GetYaxis()->CenterTitle();
		
		mg->GetXaxis()->SetTitleOffset(1.5);
		mg->GetYaxis()->SetTitleOffset(2);
		
		// mg->GetXaxis()->SetLimits(1,100000.);
		
		// mg->SetMaximum(5e-25); 
		// mg->SetMinimum(1e-35); 
		
		
		TGaxis *axisX = new TGaxis(TMath::Power(10, gPad->GetUxmin()),gPad->GetUymax(),
		TMath::Power(10, gPad->GetUxmax()), gPad->GetUymax(),
		mg->GetXaxis()->GetXmin(),
		mg->GetXaxis()->GetXmax(), 510,"GU-");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX->Draw();
		
		
		TGaxis *axisY = new TGaxis(TMath::Power(10, gPad->GetUxmax()),gPad->GetUymin(),
		TMath::Power(10, gPad->GetUxmax()), gPad->GetUymax(),
		mg->GetYaxis()->GetXmin(),
		mg->GetYaxis()->GetXmax(), 510,"U+");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY->Draw();
		
		
		
		TLegend* leg = new TLegend(.15,.7,.42,.9);
		leg->SetFillColor(0);	
		// leg->SetTextSize(0.06);
		
		
		TString Tnum1 = sInt(num1);		
		TString Tnum2 = sInt(num2);	
		
		// TString name1 = "EPICS2017 - "+ Tnum1 + " points";
		// TString name2 = "Livermore - "+ Tnum2 + " points";	
		TString name1 = "EPICS2017";
		TString name2 = "Livermore";			
		
		leg->AddEntry(graph1,name1);
		leg->AddEntry(graph2,name2);
		//leg->DrawClone("Same");
		leg->Draw();
		
		
		
		mycanvas->Print("plots/trip/comparison/comparison-tp-cs-"+ S +".png");
		mycanvas->Close();
		
		
}



void plot_trip()
{
	gROOT->Reset();
	string dirs[5] = {"plots","trip", "epics2017", "livermore", "comparison"};
	
	for (Int_t i=0;i<5;++i)
	{
		// create the 5 directories if they do not existif
		if(i==0)
		{
			dirs[i] = "mkdir -p "+dirs[i]; 
		// execute the command defined line above
		gSystem->Exec(dirs[i].c_str());
		}
		else if(i==1)
		{
			dirs[i] = "mkdir -p plots/" + dirs[i]; 
			gSystem->Exec(dirs[i].c_str());
		}
		else 
		{
			dirs[i] = "mkdir -p plots/trip/" + dirs[i];
			gSystem->Exec(dirs[i].c_str());
		}
		
	}
	
    
	for (Int_t z = 1;z<=99;++z)// number of element Z, from 1 to 100
	{
		// if((z != 1) && (z != 13) && (z != 82) && (z != 92)) continue;
	
		char path1Format[128] = "epics2017/tripdata/pp-trip-cs-%d.dat"; //prefix of the name of original data file
		char path1[128];
		
		char path2Format[128] = "livermore/tripdata/pp-trip-cs-%d.dat"; //prefix of the name of original data file
		char path2[128];
		
		sprintf(path1,path1Format, z);
		sprintf(path2,path2Format, z);
		
		plotSingle(z,1,path1);
		plotSingle(z,2,path2);			
		// plotComparison(z, path1, path2);
		plotComparison_2(z, path1, path2);
		
			
	}
	
}